
#ifndef __HW_h
#define	__HW_h


/* Define byte, word, and long word types
*/
typedef unsigned char u_char; 
typedef unsigned short int u_short;
typedef unsigned long u_long;
typedef unsigned int u_int; 


/* fixed point stuff
*/
typedef long fixed;						/* Our new fixed point type.	*/
#define itofx(x) ((x) << 8)				/* Integer to fixed point		*/
#define ftofx(x) ((x) * 256)			/* Float to fixed point			*/
#define dtofx(x) ((x) * 256)			/* Double to fixed point		*/
#define fxtoi(x) ((x) >> 8)				/* Fixed point to integer		*/
#define fxtof(x) ((float) (x) / 256)	/* Fixed point to float			*/
#define fxtod(x) ((double)(x) / 256)	/* Fixed point to double		*/
#define Mulfx(x,y) (((y) * (x)) >> 8)	/* Multiply a fixed by a fixed	*/
#define Divfx(x,y) ((y << 8) / (x))    	/* Divide a fixed by a fixed	*/


/* clock speeds, interrupt vector offsets and levels, arbitration values
*/
#define	FCRYSTAL	32768
#define	SYSCLK_W	0
#define	SYSCLK_X	1
#define	SYSCLK_Y	63
#define SYSCLK		(FCRYSTAL * 4 * (SYSCLK_Y+1) * (1 << (2 * SYSCLK_W + SYSCLK_X)))

#define SCI_BAUD            57600       /* 57.6 kbps                            */
#define QSPI_BAUD           209000      /* 209 kHz                              */
#define PIT_RATE            50	      	/* periodic interrupt timer rate        */
#define PIT_PRESCALE        0	        /* use prescale = 1 for freqs < 40 Hz 	*/

#define scidivider(baud)  (((SYSCLK >> 5)+((long)(baud)/2))/(baud))
#define qspidivider(baud) (((SYSCLK >> 1)+((long)(baud)/2))/(baud))
#if PIT_PRESCALE
#define pitdivider(freq)  (((FCRYSTAL >> 2)+((long)((PIT_PRESCALE << 9)*freq)/2))/((PIT_PRESCALE << 9)*freq))
#else
#define pitdivider(freq)  ((FCRYSTAL >> 2)/(freq))
#endif



#define SIMBASE             0xFFFA00  
#define RAMBASE             0xFFFB00  
#define QSMBASE             0xFFFC00  
#define QSMDATABASE         0xFFFD00  
#define TPUREGBASE          0xFFFE00  
#define TPUDPBASE           0xFFFF00  
#define EMURAMBASE          0xFFF000  


#define VECTORBASE          0xB0000     /* Vector Base Register value */
#define SCIVEC              0x56		/* SCI receive vector number  */
#define QSPIVEC             0x57        
#define TPUVEC              0x58    
#define PITVEC              0x40

#define SCI_IRQL            0x6
#define PIT_IRQL            0x7
#define QSPI_IRQL           0x6
#define TPU_IRQL            0x6

#define QSM_IARB            0x7  
#define TPU_IARB            0xC
#define PIT_IARB            0x5


typedef struct
{
	long  lparm1;
	long  lparm2;
	long  lparm3;
	long  lparm4;
	long  lparm5;
	long  lparm6;
	long  lparm7;
	long  lparm8;
	long  lparm9;
	long  lparm10;
	long  lparm11;
	long  lparm12;
	long  lparm13;
	long  lparm14;
	long  lparm15;
	long  lparm16;
	long  lparm17;
	long  lparm18;
	long  lparm19;
	long  lparm20;
	u_short uparm1;
	u_short uparm2;
	u_short uparm3;
	u_short uparm4;
	u_short uparm5;
	u_short uparm6;
	u_short uparm7;
	u_short uparm8;
	u_short uparm9;
	u_short uparm10;
	float fparm1;
	float fparm2;
	float fparm3;
	float fparm4;
	float fparm5;
	float fparm6;
	float fparm7;
	float fparm8;
	float fparm9;
	float fparm10;

} TMBUFF; 





#endif
